==> 4.7.4.tar.gz: terraform-provider-decort/samples/cloudapi/image/resource_image/main.tf <==
/*
Пример использования
Работа с образом
Ресурс позволяет:
1. Управлять образом
*/

#Расскомментируйте этот код,
#и внесите необходимые правки в версию и путь,
#чтобы работать с установленным вручную (не через hashicorp provider registry) провайдером
/*
terraform {
  required_providers {
    decort = {
      source = "basis/decort/decort"
      version = "<VERSION>"
    }
  }
}
*/

provider "decort" {
  authenticator = "decs3o"
  #controller_url = <DECORT_CONTROLLER_URL>
  controller_url = "https://ds1.digitalenergy.online"
  #oauth2_url = <DECORT_SSO_URL>
  oauth2_url           = "https://sso.digitalenergy.online"
  allow_unverified_ssl = true
}

resource "decort_image" "img" {
  #наименование образа
  #обязательный параметр
  #тип - строка
  name = "image_name"

  #драйверы компьютов, подходящие для данного образа
  #обязательный параметр
  #тип - массив строк
  drivers = ["KVM_X86"]

  #тип образа (linux, windows и др.)
  #обязательный параметр
  #тип - строка
  type = "linux"

  #прямая ссылка на образ
  #обязательный параметр
  #тип - строка
  url = "https://dl-cdn.alpinelinux.org/alpine/v3.17/releases/x86_64/alpine-virt-3.17.3-x86_64.iso"

  #тип загрузчика (bios/uefi)
  #обязательный параметр
  #тип - строка
  boot_type = "bios"

  #id аккаунта
  #обязательный параметр
  #тип - целое число
  account_id = 138

  #поддержка hot resize
  #опциональный параметр
  #тип - булев
  hot_resize = true

  #юзернейм для образа
  #опциональный параметр
  #тип - целое число
  username = "userx"

  #пароль для образа
  #опциональный параметр
  #тип - строка
  password = "passx"

  #юзернейм для загрузки binary media
  #опциональный параметр
  #тип - строка
  username_dl = "userxdl"

  #пароль для загрузки binary media
  #опциональный параметр
  #тип - строка
  password_dl = "passxdl"

  #storage endpoint provider ID
  #опциональный параметр
  #тип - целое число
  sep_id = 1

  #pool для образа
  #опциональный параметр
  #тип - строка
  pool_name = "pool"

  #архитектура образа (X86_64)
  #опциональный параметр
  #тип - строка
  architecture = "X86_64"

  #наименование сетевого интерфейса для вашего компьютера с Linux, eth - встроенный, ens - pci слот
  #опциональный параметр
  #тип - строка
  network_interface_naming = "ens"
}

output "img_out" {
  value = decort_image.img
}

==> 4.9.0.tar.gz: terraform-provider-decort/samples/cloudapi/image/resource_image/main.tf <==
/*
Пример использования
Работа с образом
Ресурс позволяет:
1. Управлять образом
*/

#Раскомментируйте этот код,
#и внесите необходимые правки в версию и путь,
#чтобы работать с установленным вручную (не через hashicorp provider registry) провайдером
/*
terraform {
  required_providers {
    decort = {
      source = "basis/decort/decort"
      version = "<VERSION>"
    }
  }
}
*/

provider "decort" {
  authenticator = "decs3o"
  #controller_url = <DECORT_CONTROLLER_URL>
  controller_url = "https://ds1.digitalenergy.online"
  #oauth2_url = <DECORT_SSO_URL>
  oauth2_url           = "https://sso.digitalenergy.online"
  allow_unverified_ssl = true
}

resource "decort_image" "img" {
  #наименование образа
  #обязательный параметр
  #тип - строка
  #используется при создании и обновлении
  name = "image_name"

  #драйверы компьютов, подходящие для данного образа
  #обязательный параметр
  #тип - массив строк
  #используется при создании
  drivers = ["KVM_X86"]

  #тип образа (linux, windows и др.)
  #обязательный параметр
  #тип - строка
  #используется при создании
  type = "linux"

  #прямая ссылка на образ
  #обязательный параметр
  #тип - строка
  #используется при создании
  url = "https://dl-cdn.alpinelinux.org/alpine/v3.17/releases/x86_64/alpine-virt-3.17.3-x86_64.iso"

  #тип загрузчика (bios/uefi)
  #обязательный параметр
  #тип - строка
  #используется при создании
  boot_type = "bios"

  #id аккаунта
  #обязательный параметр
  #тип - целое число
  #используется при создании
  account_id = 138

  #поддержка hot resize
  #опциональный параметр
  #тип - булев
  #используется при создании
  #hot_resize = true

  #юзернейм для образа
  #опциональный параметр
  #тип - целое число
  #используется при создании
  #username = "userx"

  #пароль для образа
  #опциональный параметр
  #тип - строка
  #используется при создании
  #password = "passx"

  #юзернейм для загрузки binary media
  #опциональный параметр
  #тип - строка
  #используется при создании
  #username_dl = "userxdl"

  #пароль для загрузки binary media
  #опциональный параметр
  #тип - строка
  #используется при создании
  #password_dl = "passxdl"

  #storage endpoint provider ID
  #опциональный параметр
  #тип - целое число
  #используется при создании
  #sep_id = 1

  #pool для образа
  #опциональный параметр
  #тип - строка
  #используется при создании
  #pool_name = "pool"

  #архитектура образа (X86_64)
  #опциональный параметр
  #тип - строка
  #используется при создании
  #architecture = "X86_64"

  #наименование сетевого интерфейса для вашего компьютера с Linux
  #eth - встроенный, ens - pci слот
  #опциональный параметр
  #тип - строка
  #используется при создании
  #network_interface_naming = "ens"
}

output "img_out" {
  value = decort_image.img
}
